summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--ANNOUNCE4
-rw-r--r--INSTALL2
-rw-r--r--LICENSE4
-rw-r--r--README2
-rw-r--r--example.c2
-rw-r--r--png.52
-rw-r--r--png.c6
-rw-r--r--pngconf.h2
-rw-r--r--pngdebug.h2
-rw-r--r--pngget.c2
-rw-r--r--pnginfo.h2
-rw-r--r--pngmem.c2
-rw-r--r--pngpread.c2
-rw-r--r--pngread.c2
-rw-r--r--pngrio.c2
-rw-r--r--pngrtran.c2
-rw-r--r--pngset.c2
-rw-r--r--pngstruct.h2
-rw-r--r--pngtest.c2
-rw-r--r--pngtrans.c2
-rw-r--r--pngwio.c2
-rw-r--r--pngwrite.c2
-rw-r--r--pngwtran.c2
-rw-r--r--pngwutil.c2
-rw-r--r--projects/vstudio/readme.txt2
-rw-r--r--projects/vstudio/zlib.props2
-rw-r--r--scripts/README.txt2
-rwxr-xr-xscripts/options.awk2
-rw-r--r--scripts/pnglibconf.dfa2
-rw-r--r--scripts/pnglibconf.h2
-rw-r--r--scripts/pngwin.dfn2
-rw-r--r--scripts/sym.dfn2
-rw-r--r--scripts/symbols.dfn2
-rw-r--r--scripts/vers.dfn2
34 files changed, 38 insertions, 38 deletions
diff --git a/ANNOUNCE b/ANNOUNCE
index 1521c1ba1..665d8cdbe 100644
--- a/ANNOUNCE
+++ b/ANNOUNCE
@@ -1,5 +1,5 @@
-Libpng 1.5.0beta36 - July 29, 2010
+Libpng 1.5.0beta36 - July 30, 2010
This is not intended to be a public release. It will be replaced
within a few weeks by a public version or by another test version.
@@ -226,7 +226,7 @@ version 1.5.0beta24 [May 7, 2010]
offset of the png_ptr->rowbuf pointer into png_ptr->big_row_buf.
Added more blank lines for readability.
-version 1.5.0beta25 [July 29, 2010]
+version 1.5.0beta25 [July 30, 2010]
In pngpread.c: png_push_have_row() add check for new_row > height
Removed the now-redundant check for out-of-bounds new_row from example.c
diff --git a/INSTALL b/INSTALL
index f3d570051..921f95a39 100644
--- a/INSTALL
+++ b/INSTALL
@@ -1,5 +1,5 @@
-Installing libpng version 1.5.0beta36 - July 29, 2010
+Installing libpng version 1.5.0beta36 - July 30, 2010
On Unix/Linux and similar systems, you can simply type
diff --git a/LICENSE b/LICENSE
index 81f884cc1..039060ff8 100644
--- a/LICENSE
+++ b/LICENSE
@@ -10,7 +10,7 @@ this sentence.
This code is released under the libpng license.
-libpng versions 1.2.6, August 15, 2004, through 1.5.0beta36, July 29, 2010, are
+libpng versions 1.2.6, August 15, 2004, through 1.5.0beta36, July 30, 2010, are
Copyright (c) 2004, 2006-2010 Glenn Randers-Pehrson, and are
distributed according to the same disclaimer and license as libpng-1.2.5
with the following individual added to the list of Contributing Authors
@@ -108,4 +108,4 @@ certification mark of the Open Source Initiative.
Glenn Randers-Pehrson
glennrp at users.sourceforge.net
-July 29, 2010
+July 30, 2010
diff --git a/README b/README
index f01c388fc..493a822d8 100644
--- a/README
+++ b/README
@@ -1,4 +1,4 @@
-README for libpng version 1.5.0beta36 - July 29, 2010 (shared library 15.0)
+README for libpng version 1.5.0beta36 - July 30, 2010 (shared library 15.0)
See the note about version numbers near the top of png.h
See INSTALL for instructions on how to install libpng.
diff --git a/example.c b/example.c
index bd229a690..60915d09f 100644
--- a/example.c
+++ b/example.c
@@ -2,7 +2,7 @@
#if 0 /* in case someone actually tries to compile this */
/* example.c - an example of using libpng
- * Last changed in libpng 1.5.0 [July 29, 2010]
+ * Last changed in libpng 1.5.0 [July 30, 2010]
* This file has been placed in the public domain by the authors.
* Maintained 1998-2010 Glenn Randers-Pehrson
* Maintained 1996, 1997 Andreas Dilger)
diff --git a/png.5 b/png.5
index c9e2a3a0f..60a2ef325 100644
--- a/png.5
+++ b/png.5
@@ -1,4 +1,4 @@
-.TH PNG 5 "July 29, 2010"
+.TH PNG 5 "July 30, 2010"
.SH NAME
png \- Portable Network Graphics (PNG) format
.SH DESCRIPTION
diff --git a/pngconf.h b/pngconf.h
index 744e6afb6..0b2b05638 100644
--- a/pngconf.h
+++ b/pngconf.h
@@ -1,7 +1,7 @@
/* pngconf.h - machine configurable file for libpng
*
- * libpng version 1.5.0beta36 - July 29, 2010
+ * libpng version 1.5.0beta36 - July 30, 2010
*
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
diff --git a/pngdebug.h b/pngdebug.h
index 123113ee9..10c7f14a2 100644
--- a/pngdebug.h
+++ b/pngdebug.h
@@ -5,7 +5,7 @@
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
*
- * Last changed in libpng version 1.5.0 - July 29, 2010
+ * Last changed in libpng version 1.5.0 - July 30, 2010
*
* This code is released under the libpng license.
* For conditions of distribution and use, see the disclaimer
diff --git a/pngget.c b/pngget.c
index 31804f031..25cd87319 100644
--- a/pngget.c
+++ b/pngget.c
@@ -1,7 +1,7 @@
/* pngget.c - retrieval of values from info struct
*
- * Last changed in libpng 1.4.1 [July 29, 2010]
+ * Last changed in libpng 1.4.1 [July 30, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pnginfo.h b/pnginfo.h
index d929edeb5..a32d78d06 100644
--- a/pnginfo.h
+++ b/pnginfo.h
@@ -5,7 +5,7 @@
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
*
- * Last changed in libpng version 1.5.0 - July 29, 2010
+ * Last changed in libpng version 1.5.0 - July 30, 2010
*
* This code is released under the libpng license.
* For conditions of distribution and use, see the disclaimer
diff --git a/pngmem.c b/pngmem.c
index dde1d349e..5ec995ed7 100644
--- a/pngmem.c
+++ b/pngmem.c
@@ -1,7 +1,7 @@
/* pngmem.c - stub functions for memory allocation
*
- * Last changed in libpng 1.5.0 [July 29, 2010]
+ * Last changed in libpng 1.5.0 [July 30, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngpread.c b/pngpread.c
index 936b2f1e7..c15a5d93d 100644
--- a/pngpread.c
+++ b/pngpread.c
@@ -1,7 +1,7 @@
/* pngpread.c - read a png file in push mode
*
- * Last changed in libpng 1.5.0 [July 29, 2010]
+ * Last changed in libpng 1.5.0 [July 30, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngread.c b/pngread.c
index 5ef250634..8de977884 100644
--- a/pngread.c
+++ b/pngread.c
@@ -1,7 +1,7 @@
/* pngread.c - read a PNG file
*
- * Last changed in libpng 1.5.0 [July 29, 2010]
+ * Last changed in libpng 1.5.0 [July 30, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngrio.c b/pngrio.c
index d3f6ec7ac..4760dd525 100644
--- a/pngrio.c
+++ b/pngrio.c
@@ -1,7 +1,7 @@
/* pngrio.c - functions for data input
*
- * Last changed in libpng 1.5.0 [July 29, 2010]
+ * Last changed in libpng 1.5.0 [July 30, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngrtran.c b/pngrtran.c
index 6fe7399cf..dbd96cc89 100644
--- a/pngrtran.c
+++ b/pngrtran.c
@@ -1,7 +1,7 @@
/* pngrtran.c - transforms the data in a row for PNG readers
*
- * Last changed in libpng 1.5.0 [July 29, 2010]
+ * Last changed in libpng 1.5.0 [July 30, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngset.c b/pngset.c
index e68ffe551..4b63b1ea8 100644
--- a/pngset.c
+++ b/pngset.c
@@ -1,7 +1,7 @@
/* pngset.c - storage of image information into info struct
*
- * Last changed in libpng 1.5.0 [July 29, 2010]
+ * Last changed in libpng 1.5.0 [July 30, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngstruct.h b/pngstruct.h
index a9d6c90e4..6f3b57cec 100644
--- a/pngstruct.h
+++ b/pngstruct.h
@@ -5,7 +5,7 @@
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
*
- * Last changed in libpng version 1.5.0 - July 29, 2010
+ * Last changed in libpng version 1.5.0 - July 30, 2010
*
* This code is released under the libpng license.
* For conditions of distribution and use, see the disclaimer
diff --git a/pngtest.c b/pngtest.c
index 07dc466f1..4249e5bc3 100644
--- a/pngtest.c
+++ b/pngtest.c
@@ -1,7 +1,7 @@
/* pngtest.c - a simple test program to test libpng
*
- * Last changed in libpng 1.5.0 [July 29, 2010]
+ * Last changed in libpng 1.5.0 [July 30, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngtrans.c b/pngtrans.c
index d48ab369b..c95b4a0be 100644
--- a/pngtrans.c
+++ b/pngtrans.c
@@ -1,7 +1,7 @@
/* pngtrans.c - transforms the data in a row (used by both readers and writers)
*
- * Last changed in libpng 1.5.0 [July 29, 2010]
+ * Last changed in libpng 1.5.0 [July 30, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngwio.c b/pngwio.c
index 20955af40..714086e6a 100644
--- a/pngwio.c
+++ b/pngwio.c
@@ -1,7 +1,7 @@
/* pngwio.c - functions for data output
*
- * Last changed in libpng 1.5.0 [July 29, 2010]
+ * Last changed in libpng 1.5.0 [July 30, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngwrite.c b/pngwrite.c
index de30bdd5f..a7f69db9b 100644
--- a/pngwrite.c
+++ b/pngwrite.c
@@ -1,7 +1,7 @@
/* pngwrite.c - general routines to write a PNG file
*
- * Last changed in libpng 1.5.0 [July 29, 2010]
+ * Last changed in libpng 1.5.0 [July 30, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngwtran.c b/pngwtran.c
index dff65850a..55a2e8d9b 100644
--- a/pngwtran.c
+++ b/pngwtran.c
@@ -1,7 +1,7 @@
/* pngwtran.c - transforms the data in a row for PNG writers
*
- * Last changed in libpng 1.5.0 [July 29, 2010]
+ * Last changed in libpng 1.5.0 [July 30, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/pngwutil.c b/pngwutil.c
index ced9f0f2f..a6721681c 100644
--- a/pngwutil.c
+++ b/pngwutil.c
@@ -1,7 +1,7 @@
/* pngwutil.c - utilities to write a PNG file
*
- * Last changed in libpng 1.5.0 [July 29, 2010]
+ * Last changed in libpng 1.5.0 [July 30, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
diff --git a/projects/vstudio/readme.txt b/projects/vstudio/readme.txt
index 486622a44..5ad4069e4 100644
--- a/projects/vstudio/readme.txt
+++ b/projects/vstudio/readme.txt
@@ -1,7 +1,7 @@
VisualStudio instructions
-libpng version 1.5.0beta36 - July 29, 2010
+libpng version 1.5.0beta36 - July 30, 2010
Copyright (c) 1998-2010 Glenn Randers-Pehrson
diff --git a/projects/vstudio/zlib.props b/projects/vstudio/zlib.props
index 39a98d802..f7250a094 100644
--- a/projects/vstudio/zlib.props
+++ b/projects/vstudio/zlib.props
@@ -2,7 +2,7 @@
<!--
* zlib.props - location of zlib source and build
*
- * libpng version 1.5.0beta36 - July 29, 2010
+ * libpng version 1.5.0beta36 - July 30, 2010
*
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
*
diff --git a/scripts/README.txt b/scripts/README.txt
index 7109ef943..3d97addea 100644
--- a/scripts/README.txt
+++ b/scripts/README.txt
@@ -1,5 +1,5 @@
-Makefiles for libpng version 1.5.0beta36 - July 29, 2010
+Makefiles for libpng version 1.5.0beta36 - July 30, 2010
pnglibconf.h => Stores configuration settings
makefile.linux => Linux/ELF makefile
diff --git a/scripts/options.awk b/scripts/options.awk
index 67b4626b6..2730c3fa4 100755
--- a/scripts/options.awk
+++ b/scripts/options.awk
@@ -1,7 +1,7 @@
#!/bin/awk -f
# scripts/options.awk - library build configuration control
#
-# last changed in libpng version 1.5.0 - July 29, 2010
+# last changed in libpng version 1.5.0 - July 30, 2010
#
# Copyright (c) 1998-2010 Glenn Randers-Pehrson
#
diff --git a/scripts/pnglibconf.dfa b/scripts/pnglibconf.dfa
index 6e8e8b43c..e1b16ddad 100644
--- a/scripts/pnglibconf.dfa
+++ b/scripts/pnglibconf.dfa
@@ -6,7 +6,7 @@
#
com pnglibconf.h - library build configuration
com
-com libpng version PNGLIB_VERSION - last changed on July 29, 2010
+com libpng version PNGLIB_VERSION - last changed on July 30, 2010
com
com Copyright (c) 1998-2010 Glenn Randers-Pehrson
com
diff --git a/scripts/pnglibconf.h b/scripts/pnglibconf.h
index 4469b0f20..b50babdc1 100644
--- a/scripts/pnglibconf.h
+++ b/scripts/pnglibconf.h
@@ -1,7 +1,7 @@
/* libpng-1.5.0beta36 STANDARD API DEFINITION */
/* pnglibconf.h - library build configuration */
-/* last changed in libpng version 1.5.0 - July 29, 2010 */
+/* last changed in libpng version 1.5.0 - July 30, 2010 */
/* Copyright (c) 1998-2010 Glenn Randers-Pehrson */
diff --git a/scripts/pngwin.dfn b/scripts/pngwin.dfn
index 9fd159f30..a6550df98 100644
--- a/scripts/pngwin.dfn
+++ b/scripts/pngwin.dfn
@@ -1,7 +1,7 @@
/* pngwin.dfn - define format of pngwin.def
*
- * Last changed in libpng version 1.5.0 [July 29, 2010]
+ * Last changed in libpng version 1.5.0 [July 30, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
*
* This code is released under the libpng license.
diff --git a/scripts/sym.dfn b/scripts/sym.dfn
index 42a802dd0..9e72fed2a 100644
--- a/scripts/sym.dfn
+++ b/scripts/sym.dfn
@@ -1,7 +1,7 @@
/* sym.dfn - define format of libpng.sym
*
- * Last changed in libpng version 1.5.0 [July 29, 2010]
+ * Last changed in libpng version 1.5.0 [July 30, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
*
* This code is released under the libpng license.
diff --git a/scripts/symbols.dfn b/scripts/symbols.dfn
index fd2fce290..85d67063d 100644
--- a/scripts/symbols.dfn
+++ b/scripts/symbols.dfn
@@ -1,7 +1,7 @@
/* symbols.dfn - find all exported symbols
*
- * Last changed in libpng version 1.5.0 [July 29, 2010]
+ * Last changed in libpng version 1.5.0 [July 30, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
*
* This code is released under the libpng license.
diff --git a/scripts/vers.dfn b/scripts/vers.dfn
index 2ef4c203c..d1979f180 100644
--- a/scripts/vers.dfn
+++ b/scripts/vers.dfn
@@ -1,7 +1,7 @@
/* vers.dfn - define format of libpng.vers
*
- * Last changed in libpng version 1.5.0 [July 29, 2010]
+ * Last changed in libpng version 1.5.0 [July 30, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
*
* This code is released under the libpng license.
diff --git a/png.c b/png.c
index 8425ff3b2..28537d910 100644
--- a/png.c
+++ b/png.c
@@ -1,7 +1,7 @@
/* png.c - location for general purpose libpng functions
*
* Last changed in libpng 1.5.0 [July 29, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)
* (Version 0.88 Copyright (c) 1995, 1996 Guy Eric Schalnat, Group 42, Inc.)
@@ -560,13 +560,13 @@ png_get_copyright(png_structp png_ptr)
#else
# ifdef __STDC__
return ((png_charp) PNG_STRING_NEWLINE \
- "libpng version 1.5.0beta36 - July 29, 2010" PNG_STRING_NEWLINE \
+ "libpng version 1.5.0beta36 - July 30, 2010" PNG_STRING_NEWLINE \
"Copyright (c) 1998-2010 Glenn Randers-Pehrson" PNG_STRING_NEWLINE \
"Copyright (c) 1996-1997 Andreas Dilger" PNG_STRING_NEWLINE \
"Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc." \
PNG_STRING_NEWLINE);
# else
- return ((png_charp) "libpng version 1.5.0beta36 - July 29, 2010\
+ return ((png_charp) "libpng version 1.5.0beta36 - July 30, 2010\
Copyright (c) 1998-2010 Glenn Randers-Pehrson\
Copyright (c) 1996-1997 Andreas Dilger\
Copyright (c) 1995-1996 Guy Eric Schalnat, Group 42, Inc.");
@@ -1,7 +1,7 @@
/* png.c - location for general purpose libpng functions
*
- * Last changed in libpng 1.5.0 [July 29, 2010]
+ * Last changed in libpng 1.5.0 [July 30, 2010]
* Copyright (c) 1998-2010 Glenn Randers-Pehrson
* (Version 0.96 Copyright (c) 1996, 1997 Andreas Dilger)